<?php

namespace App\Repositories\Eloquent;

use App\Repositories\Contracts\ThirdApiPlatformRepository;
use App\Repositories\Criteria\RequestCriteria;
use App\Repositories\Eloquent\BaseRepository;

use App\Repositories\Models\ThirdApiPlatform;
use Illuminate\Container\Container as Application;
use Prettus\Validator\Contracts\ValidatorInterface;

/**
 * Class UserRepositoryEloquent.
 */
class ThirdApiPlatformRepositoryEloquent extends BaseRepository implements ThirdApiPlatformRepository
{
    protected $fieldSearchable = [
        'platform_name', 'platform_title',
    ];

    /**
     * 定义validator的检索规则
     * @var \string[][]
     */
    public $rules = [
        ValidatorInterface::RULE_CREATE => [
            'platform_name'   => 'required',
            'platform_title'  => 'required',
            'platform_type'   => 'required',
            'platform_token'  => 'required',
            'platform_status' => 'required',
        ],
        ValidatorInterface::RULE_UPDATE => [
            'platform_name'   => 'required',
            'platform_title'  => 'required',
            'platform_type'   => 'required',
            'platform_token'  => 'required',
            'platform_status' => 'required',
        ]
    ];

    /**
     * Specify Model class name.
     *
     * @return string
     */
    public function model()
    {
        return ThirdApiPlatform::class;
    }

    /**
     * Boot up the repository, pushing criteria.
     *
     * @throws \Prettus\Repository\Exceptions\RepositoryException
     */
    public function boot()
    {
        $this->pushCriteria(app(RequestCriteria::class));
    }

    public function getPlatformInfoByPlatformName($platformName)
    {
        $platformInfo = $this->findWhere(['platform_name' => $platformName]);
        if($platformInfo){
            $platformInfo = $platformInfo[0];
            return $platformInfo->toArray();
        }
        return null;
    }
}
